@@ -142,7 +142,7 @@ class OpenPR:
                     "Enter the description of the pull request. Pressing enter will open the default editor"
                 )
         description = prompt_utils.ask_questions_editor(
-            "Enter the description of the PR: ", pr_body
+            question_text="Enter the description of the PR: ", default_text=pr_body
         )
         if description == "":
             logger.warning("The description of the pull request cannot be empty")
